@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -37,7 +37,7 @@ package com.sun.javafx.runtime;
  * System Properties at the loading of the JavaFX Toolkit. The JavaFX properties
  * are javafx.version and javafx.runtime.version. Their formats follow the
  * specification of java.version and java.runtime.version respectively.
- * See http://openjdk.java.net/jeps/223 for details.
+ * See https://openjdk.org/jeps/223 for details.
  *
  * For example, an early access build of JavaFX 9 build 76 will contain
  * the following properties:
@@ -84,7 +84,7 @@ public class VersionInfo {
     /**
      * Build Timestamp.
      */
-    private static final String BUILD_TIMESTAMP = "2024-10-17-173314";
+    private static final String BUILD_TIMESTAMP = "2024-10-17-154713";
 
     /**
      * Hudson Job Name.
@@ -96,58 +96,27 @@ public class VersionInfo {
      */
     private static final String HUDSON_BUILD_NUMBER = "0000";
 
-    /**
-     * Promoted build number used as part of the runtime version string.
-     */
-    private static final String PROMOTED_BUILD_NUMBER = "0";
-
-    /**
-     * Raw Version number string. (without milestone tag)
-     */
-    private static final String RELEASE_VERSION = "17";
-
     /**
      * Release suffix.
      */
     private static final String RELEASE_SUFFIX = "-internal";
 
     /**
-     * The composite version string. This is composed in the static
-     * initializer for this class.
+     * The composite version string.
      */
-    private static final String VERSION;
+    private static final String VERSION = "22-internal";
 
     /**
      * The composite version string include build number.
-     * This is composed in the static initializer for this class.
      */
-    private static final String RUNTIME_VERSION;
-
-    // The static initializer composes the VERSION and RUNTIME_VERSION strings
-    static {
-        String tmpVersion = RELEASE_VERSION;
-
-        // Construct the VERSION string adding milestone information,
-        // such as beta, if present.
-        // Note: RELEASE_SUFFIX is expected to be empty for fcs versions
-        tmpVersion += RELEASE_SUFFIX;
-        VERSION = tmpVersion;
-
-        // Append the RUNTIME_VERSION string that follow the VERSION string
-        tmpVersion += "+" + PROMOTED_BUILD_NUMBER;
-        if (getHudsonJobName().length() == 0) {
-            // Non hudson (developer) build
-            tmpVersion += "-" + BUILD_TIMESTAMP;
-        }
-        RUNTIME_VERSION = tmpVersion;
-    }
+    private static final String RUNTIME_VERSION = "22-internal+0-2024-10-17-154713";
 
     /**
      * Setup the System properties with JavaFX API version information.
      * The format of the value strings of javafx.version and javafx.runtime.version
      * will follow the same pattern as java.version and java.runtime.version
      * respectively.
-     * See http://openjdk.java.net/jeps/223 for details.
+     * See https://openjdk.org/jeps/223 for details.
      */
     public static synchronized void setupSystemProperties() {
         if (System.getProperty("javafx.version") == null) {
