@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,7 +38,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.13";
+        "21.0.5";
 
     private static final String java_version_date =
         "2024-10-15";
@@ -49,13 +49,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.13+11-adhoc.root.jdk17u";
+        "21.0.5+11-adhoc.root.jdk21u";
 
     private static final String VERSION_NUMBER =
-        "17.0.13";
+        "21.0.5";
 
     private static final String VERSION_SPECIFICATION =
-        "17";
+        "21";
 
     private static final String VERSION_BUILD =
         "11";
@@ -64,13 +64,13 @@ class VersionProps {
         "";
 
     private static final String VERSION_OPT =
-        "adhoc.root.jdk17u";
+        "adhoc.root.jdk21u";
 
     private static final boolean isLTS =
-        "adhoc.root.jdk17u".startsWith("LTS");
+        "adhoc.root.jdk21u".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "61.0";
+        "65.0";
 
     private static final String VENDOR =
         "OpenLogic-OpenJDK";
@@ -109,7 +109,10 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
-        props.put("java.specification.maintenance.version", "1");
+
+        // Uncomment next props.put call after the first maintenance release for a
+        // platform specification is done and set the MR number, starting at "1".
+        // props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
@@ -183,25 +186,13 @@ class VersionProps {
         }
     }
 
-    /**
-     * In case you were wondering this method is called by java -version.
-     */
-    public static void print(boolean err) {
-        print(err, false);
-    }
 
-    /**
-     * This is the same as print except that it adds an extra line-feed
-     * at the end, typically used by the -showversion in the launcher
-     */
-    public static void println(boolean err) {
-        print(err, true);
-    }
 
     /**
      * Print version info.
+     * In case you were wondering this method is called by java -version.
      */
-    private static void print(boolean err, boolean newln) {
+    private static void print(boolean err) {
         PrintStream ps = err ? System.err : System.out;
 
         /* First line: platform version. */
